RocketCEA Wraps The NASA Fortran CEA Code And Provides Some Useful Tools — RocketCEA v1.1.25 documentation

# RocketCEA Wraps The NASA Fortran CEA Code And Provides Some Useful Tools

See the Code at: https://github.com/sonofeft/RocketCEA

See the Docs at: http://rocketcea.readthedocs.org/en/latest/

See PyPI page at:https://pypi.python.org/pypi/rocketcea

See NASA CEA HomePage at: https://www1.grc.nasa.gov/research-and-engineering/ceaweb/

See NASA CEA On-Line at: https://cearun.grc.nasa.gov/

RocketCEA makes direct calls to the NASA FORTRAN CEA code in “rocket” mode to calculate Isp, Cstar, Tcham etc. and provides tools to help determine useful mixture ratio range, optimum MR and more.

RocketCEA does not use the FORTRAN CEA2.f file directly.

Many modifications have been made in order to wrap CEA with f2py to build a python module.

Additional changes to CEA2.f have been made in order to properly handle hydrazine monopropellant’s ammonia dissociation.

Although the default units in RocketCEA are English units, SI units may be used for both input and output as well. (See Simple Examples > Transport Properties in Docs)

See NASA CEA Documentation: CEA User Manual (NASA RP-1311).pdf and CEA Methodology (NASA RP-1311).pdf

Note

For those interested in using RocketCEA to design rocket thrusters, there are two companion projects RocketIsp and RocketProps.

RocketIsp uses a simplified JANNAF approach to calculate delivered specific impulse (Isp) for liquid rocket thrust chambers.

RocketProps calculates the various liquid propellant properties required to analyse a liquid propellant thrust chamber.

Note

Python 3.8 on Windows has been problematic and is not fully supported.

Python 3.8 64 bit on Windows has been made to work by using the new os.add_dll_directory command to locate MinGW DLL libraries, however, 32 bit python 3.8 is not yet supported.

# RocketCEA

Contents:

- QuickStart
  - Install Numpy & Matplotlib
  - Install Compiler
  - Install RocketCEA
  - Windows Batch File
  - Getting Help
  - Running RocketCEA
  - Test The Install
  - Google Colaboratory
  - Windows 10 with WSL
- Install gfortran
  - Debian/Ubuntu
  - CentOS/RHEL
  - OpenSUSE
  - MacOS/OSX
  - Windows 10
- Standard Examples
  - LOX/LH2 Performance
  - Transport Properties
  - Frozen Performance
- Traditional Example
- Simple Examples
  - Simple SI Units Example
  - N2O4/MMH Performance
  - LOX/LH2 Delta V
- Finite Area Combustor
  - CEA fac Option
  - Specify Plenum Pressure
  - System Performance
- Species Mole Fractions
  - Species Mass Fractions
- Engine Mixture Ratio
  - Chemical Kinetics
  - LOX/RP1 GG vs SC
  - LOX/LH2 Bulk Density
- Propellant Selection
  - Rough Screening
  - Stage Density
  - Volume Limit
  - Delta V Requirement
  - Mass Limit
  - Monopropellants
- Propellants
  - Special Blends
  - Oxidizers
  - Fuels
  - Monoprop & Solid
- New Propellants
  - New Ox and Fuel
  - New Monoprop
- Plot Examples
  - Cstar Plot
  - Isp Plot
  - Isp Comparisons
- Ambient Isp
  - IspAmb Equation
  - Estimate IspAmb
  - Thrust Coefficient
  - Nozzle Flow Separation
- Hydrazine Monopropellant
  - Chemical Reactions
  - CEA Modification
  - Performance Plot
- Temperature Adjust
  - Standard T and H
  - Changing T and H
- CEA vs TDK vs RPA
  - Chart Description
  - LOX/LH2
  - LOX/CH4
  - LOX/RP1
  - LOX/Ethanol
  - Peroxide90/Ethanol
  - N2O4/MMH
  - N2O4/N2H4
  - MON25/MHF3
  - CLF5/N2H4
- Parasol Example
- RocketCEA Functions
  - CEA_Obj Functions
  - CEA_Obj With Units
  - User Units
  - Blend Functions
- Copyright
  - License
- Authors
  - Development Lead
  - Patches and Ideas
  - Initial Project Layout
- History
  - GitHub Log
  - PyHatch

# Indices and tables

- Index

- Module Index

- Search Page